@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::AVAR;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use 5.10.0;
 use Moose;
@@ -59,7 +59,7 @@ sub bundle_config {
         [
             MetaNoIndex => {
                 # Ignore these if they're there
-                directory => [ map { -d $_ ? $_ : () } qw( inc t xt utils ) ],
+                directory => [ map { -d $_ ? $_ : () } qw( inc t xt utils example examples ) ],
             }
         ],
         # Produce README from lib/
@@ -132,6 +132,8 @@ It's equivalent to:
     directory = t
     directory = xt
     directory = utils
+    directory = example
+    directory = examples
     
     [ReadmeFromPod]
 
